MoinMoin — a lightweight open-source wiki engine
================================================

<img src="https://github.com/moinwiki/moin/blob/master/src/moin/static/logos/moinmoin.svg?raw=true" alt="MoinMoin Logo" width="120" align="right">

MoinMoin is an easy-to-use, full-featured, and extensible wiki software package
written in Python. You can run it on all common operating systems (Windows,
macOS, Linux, etc.).

This wiki software can fulfill a wide range of roles, such as a personal notes
organizer deployed on a laptop or home web server, a company knowledge base
deployed on an intranet, or an Internet server open to individuals sharing the
same interests, goals, or projects.


Documentation and Support
=========================

> [!NOTE]
> Moin2 is not released yet.

You will find the latest documentation at https://moin-20.readthedocs.io/en/latest.

There is a wiki page collecting all Moin2-specific information, links to
support resources, and information about MoinMoin’s development status and plans:
https://moinmo.in/MoinMoin2.0

In general, ensure that the documentation you are reading
is written for the Moin version you are using. Much of the information
you find in the wiki refers to Moin 1.9 and does not apply to Moin2.

For support, please try the documentation, the home page, the IRC channel,
the mailing lists, and GitHub issues before contacting the MoinMoin
authors directly.

If you have trouble with any web server configuration, please try reading
the web server's documentation. The same applies to any other third-party
software commonly used with Moin but not written by the MoinMoin developers.


Contributing
============

You're welcome to help us make MoinMoin even better! Whether you have experience
with Python, HTML, or CSS, or are just starting out, there are many ways you
can contribute — please see [CONTRIBUTING](https://github.com/moinwiki/moin/blob/master/CONTRIBUTING.md).


Acknowledgments
================

We thank the many people who have contributed their valuable ideas, time, and
code — please see the [contributors](https://github.com/moinwiki/moin/graphs/contributors) page.
